import face_recognition


def load_image(file_path):
    return face_recognition.load_image_file(file_path)


def get_face_encodings(image):
    return face_recognition.face_encodings(image)


def compare_faces(known_face_encodings, face_encoding_to_check, tolerance=0.6):
    return face_recognition.compare_faces(known_face_encodings, face_encoding_to_check, tolerance)




from setuptools import setup, find_packages

setup(
    name="face_genius",
    version="0.1.1",
    author="VT",
    author_email="vic.tkachev@gmail.com",
    description="A simple face recognition example package",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/victk/face_genius",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.11',
    install_requires=[
        "face_recognition",
    ],
)



import unittest
from face_genius import load_image, get_face_encodings, compare_faces


class TestFaceGenius(unittest.TestCase):

    def test_face_recognition(self):
        image = load_image("test_image.jpg")

        encodings = get_face_encodings(image)

        self.assertEqual(len(encodings), 1)

        result = compare_faces(encodings, encodings[0])
        self.assertTrue(result[0])


if __name__ == "__main__":
    unittest.main()
